==> ads_1.2-5.tar.gz: ads/src/Zlibs.h <==
double un_point(double,double,double,double,double,double,double,double,double);
double deux_point(double,double,double,double,double,double,double,double,double);
double ununun_point(double,double,double,double,double,double,double,double,double);
double trois_point(double,double,double,double,double,double,double,double,double);
double deuxun_point(double,double,double,double,double,double,double,double,double);
double deuxbord_point(double,double,double,double,double,double,double,double,double);

int in_droite(double,double,double,double,double,double,double,double,int);
int in_triangle(double,double,double,double,double,double,double,double,int);

void ic(int,int,double **,double **,double *,double *,int);

double perim_in_rect(double, double, double, double, double, double, double);
double perim_in_disq(double,double,double,double,double,double);
double perim_triangle(double,double,double,int,double *,double *,double *,double *,double *,double *);

int ripley_rect(int*,double*,double*,double*,double*,double*,double*,int*,double*,double*,double*);
int ripley_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripley_tr_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,
	double *,double *,double *,double *,int *,double *,double *,double *);
int ripley_tr_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,
	double *,double *,int *,double *,double *,double *);

int ripley_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *,double *,int *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_tr_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *, double *,
	double *,double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_tr_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *, double *, double *,
	double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *);

int ripleylocal_rect(int*,double *,double *,double*,double*,double*,double*,int*,double*,double *,double *);
int ripleylocal_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripleylocal_tr_rect(int *,double *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripleylocal_tr_disq(int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

int density_rect(int*,double*,double*,double*,double*,double*,double*,int*,double*,double*,double*,int*,double*);
int density_disq(int*,double *,double *,double*,double*,double*,int*,double*,double *,double *,int*,double *);
int density_tr_rect(int*,double *,double *,double*,double*,double*,double*,int*,double *,double *,double *,
	double *,double *,double *,int*,double*,double *,double *,int*,double *);
int density_tr_disq(int*,double *,double *,double*,double*,double*,int*,double *,double *,double *,double *,
	double *,double *,int*,double*,double *,double *,int*,double *);

int intertype_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	int *,double *,double *,double *);
int intertype_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *);
int intertype_tr_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int intertype_tr_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

int intertype_rect_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	double *,int *,double *,int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *);
int intertype_disq_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,
	double *,int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *);
int intertype_tr_rect_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	double *,int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int intertype_tr_disq_ic(int *,double *,double *,int *, double *, double *,double *,double *,double *,double *,
	int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);

int intertypelocal_rect(int*,double *,double *,int*,double *,double *,double*,double*,double*,double*,
	int*,double*,double *,double *);
int intertypelocal_disq(int *,double *,double *,int *,double *,double *,double *,double *,	double *,int *,
	double *,double *,double *);
int intertypelocal_tr_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int intertypelocal_tr_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

void s_alea_rect(int,double[],double[],double,double,double,double,double);
void s_alea_disq(int,double *,double *,double,double,double,double);
void s_alea_tr_rect(int,double *,double *,double,double,double,double,int,double *,double *,double *,double *,
	double *,double *,double);
void s_alea_tr_disq(int ,double *,double *,double,double,double,int,double *,double *,double *,double *,
	double *,double *,double);

int randlabelling(double *, double *, int, double *, double *,int, double *, double *,int *);
int randshifting_rect(int *,double *,double *,int,double *,double *,double,double,double,double,double);
int randshifting_disq(int *,double *,double *,int,double *,double *,double,double,double,double);
int randshifting_tr_rect(int *,double *,double *,int,double *,double *,double,double,double,double,int,
	double *,double *,double *,double *,double *,double *,double);
int randshifting_tr_disq(int *,double *,double *,int,double *,double *,double,double,double,int,
	double *,double *,double *,double *,double *,double *,double);

int corr_rect(int *,double *,double *,double *, double *,double *,double *,double *,
int *,double *,double *,double *);
int corr_disq(int *,double *,double *,double *, double *,double *,double *,
int *,double *,double *,double *);
int corr_tr_rect(int *,double *,double *,double *, double *,double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,double *,double *);
int corr_tr_disq(int *,double *,double *,double *, double *,double *,double *,
int *,double *,double *,double *,double *,double *,double *,
int *,double *,double *,double *);

int corr_rect_ic(int *,double *,double *,double *, double *,double *,double *,double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_disq_ic(int *,double *,double *,double *, double *,double *,double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_tr_rect_ic(int *,double *,double *,double *, double *,double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_tr_disq_ic(int *,double *x,double *,double *, double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);

void randmark(int ,double *,double *);

==> ads_1.3-1.tar.gz: ads/src/Zlibs.h <==
double un_point(double,double,double,double,double,double,double,double,double);
double deux_point(double,double,double,double,double,double,double,double,double);
double ununun_point(double,double,double,double,double,double,double,double,double);
double trois_point(double,double,double,double,double,double,double,double,double);
double deuxun_point(double,double,double,double,double,double,double,double,double);
double deuxbord_point(double,double,double,double,double,double,double,double,double);

int in_droite(double,double,double,double,double,double,double,double,int);
int in_triangle(double,double,double,double,double,double,double,double,int);

void ic(int,int,double **,double **,double *,double *,int);

double perim_in_rect(double, double, double, double, double, double, double);
double perim_in_disq(double,double,double,double,double,double);
double perim_triangle(double,double,double,int,double *,double *,double *,double *,double *,double *);

int ripley_rect(int*,double*,double*,double*,double*,double*,double*,int*,double*,double*,double*);
int ripley_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripley_tr_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,
	double *,double *,double *,double *,int *,double *,double *,double *);
int ripley_tr_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *,double *,
	double *,double *,int *,double *,double *,double *);

int ripley_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *,double *,int *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_tr_rect_ic(int *,double *,double *,double *,double *,double *,double *,double *,int *, double *,
	double *,double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *);
int ripley_tr_disq_ic(int *,double *,double *,double *,double *,double *,double *,int *, double *, double *,
	double *,double *,double *,double *,int *,double *,int *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *);

int ripleylocal_rect(int*,double *,double *,double*,double*,double*,double*,int*,double*,double *,double *);
int ripleylocal_disq(int *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripleylocal_tr_rect(int *,double *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int ripleylocal_tr_disq(int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

int density_rect(int*,double*,double*,double*,double*,double*,double*,int*,double*,double*,double*,int*,double*);
int density_disq(int*,double *,double *,double*,double*,double*,int*,double*,double *,double *,int*,double *);
int density_tr_rect(int*,double *,double *,double*,double*,double*,double*,int*,double *,double *,double *,
	double *,double *,double *,int*,double*,double *,double *,int*,double *);
int density_tr_disq(int*,double *,double *,double*,double*,double*,int*,double *,double *,double *,double *,
	double *,double *,int*,double*,double *,double *,int*,double *);

int intertype_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	int *,double *,double *,double *);
int intertype_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *);
int intertype_tr_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int intertype_tr_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

int intertype_rect_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	double *,int *,double *,int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *,double *);
int intertype_disq_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,int *,
	double *,int *,int *,double *,double *,double *,double *,double *,double *,double *,double *,double *,
	double *,double *,double *,double *);
int intertype_tr_rect_ic(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	double *,int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);
int intertype_tr_disq_ic(int *,double *,double *,int *, double *, double *,double *,double *,double *,double *,
	int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,double *,double *,
	double *,double *,double *,double *,double *,double *,double *,double *,double *,double *);

int intertypelocal_rect(int*,double *,double *,int*,double *,double *,double*,double*,double*,double*,
	int*,double*,double *,double *);
int intertypelocal_disq(int *,double *,double *,int *,double *,double *,double *,double *,	double *,int *,
	double *,double *,double *);
int intertypelocal_tr_rect(int *,double *,double *,int *,double *,double *,double *,double *,double *,double *,
	int *,double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);
int intertypelocal_tr_disq(int *,double *,double *,int *,double *,double *,double *,double *,double *,int *,
	double *,double *,double *,double *,double *,double *,int *,double *,double *,double *);

void s_alea_rect(int,double[],double[],double,double,double,double,double);
void s_alea_disq(int,double *,double *,double,double,double,double);
void s_alea_tr_rect(int,double *,double *,double,double,double,double,int,double *,double *,double *,double *,
	double *,double *,double);
void s_alea_tr_disq(int ,double *,double *,double,double,double,int,double *,double *,double *,double *,
	double *,double *,double);

int randlabelling(double *, double *, int, double *, double *,int, double *, double *,int *);
int randshifting_rect(int *,double *,double *,int,double *,double *,double,double,double,double,double);
int randshifting_disq(int *,double *,double *,int,double *,double *,double,double,double,double);
int randshifting_tr_rect(int *,double *,double *,int,double *,double *,double,double,double,double,int,
	double *,double *,double *,double *,double *,double *,double);
int randshifting_tr_disq(int *,double *,double *,int,double *,double *,double,double,double,int,
	double *,double *,double *,double *,double *,double *,double);
int randomlab(double *,double *,int,int *,int,double **,int *,double **);
void randmark(int ,double *,double *);

int corr_rect(int *,double *,double *,double *, double *,double *,double *,double *,
int *,double *,double *,double *);
int corr_disq(int *,double *,double *,double *, double *,double *,double *,
int *,double *,double *,double *);
int corr_tr_rect(int *,double *,double *,double *, double *,double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,double *,double *);
int corr_tr_disq(int *,double *,double *,double *, double *,double *,double *,
int *,double *,double *,double *,double *,double *,double *,
int *,double *,double *,double *);

int corr_rect_ic(int *,double *,double *,double *, double *,double *,double *,double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_disq_ic(int *,double *,double *,double *, double *,double *,double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_tr_rect_ic(int *,double *,double *,double *, double *,double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);
int corr_tr_disq_ic(int *,double *x,double *,double *, double *,double *,double *,
int *, double *, double *, double *, double *, double *, double *,
int *,double *,int *, double *,double *,double *,
double *,double *, double *,double *, double *, double *);

int shimatani_rect(int *,double *,double *,double *,double *,double *,double *,int *,double *,int *,int *,double *,double *, double *,int *);
int shimatani_disq(int *,double *,double *, double *,double *,double *,int *,double *,int *,int *,double *,double *, double *,int *);
int shimatani_tr_rect(int *,double *,double *, double *,double *,double *,double *,int *, double *, double *, double *, double *, double *, double *,
					  int *,double *,int *,int *,double *,double *, double *,int *);
int shimatani_tr_disq(int *,double *,double *, double *,double *,double *,int *, double *, double *, double *, double *, double *, double *,
					  int *,double *,int *,int *,double *,double *, double *,int *);
int shimatani_rect_ic(int *,double *,double *, double *,double *,double *,double *,int *,double *,int *,double *,int *,int *,double *,double *,
					  double *, double *,double *,double *,double *,double *,double *,double *,int *);
int shimatani_disq_ic(int *,double *,double *, double *,double *,double *,int *,double *,int *,double *,int *,int *,double *,double *,
					  double *, double *,double *,double *,double *,double *,double *,double *,int *);
int shimatani_tr_rect_ic(int *,double *,double *, double *,double *,double *,double *,int *, double *, double *, double *, double *, double *, double *,
						 int *,double *,int *,double *,int *,int *,double *,double *,double *, double *,double *,double *,double *,double *,double *,double *,int *);
int shimatani_tr_disq_ic(int *,double *,double *, double *,double *,double *,int *, double *, double *, double *, double *, double *, double *,
						 int *,double *,int *,double *,int *,int *,double *,double *,double *, double *,double *,double *,double *,double *,double *,double *,int *);
